==> apache-servicecomb-pack-distribution-0.3.0-src.zip: apache-servicecomb-pack-distribution-0.3.0-src/omega/omega-transaction/src/main/java/org/apache/servicecomb/pack/omega/transaction/tcc/TccEventService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.pack.omega.transaction.tcc;

import org.apache.servicecomb.pack.omega.transaction.tcc.events.CoordinatedEvent;
import org.apache.servicecomb.pack.omega.transaction.tcc.events.ParticipatedEvent;
import org.apache.servicecomb.pack.omega.transaction.tcc.events.TccStartedEvent;
import org.apache.servicecomb.pack.omega.transaction.AlphaResponse;
import org.apache.servicecomb.pack.omega.transaction.tcc.events.TccEndedEvent;

public interface TccEventService {

  void onConnected();

  void onDisconnected();

  void close();

  String target();

  AlphaResponse participate(ParticipatedEvent participatedEvent);

  AlphaResponse tccTransactionStart(TccStartedEvent tccStartedEvent);

  AlphaResponse tccTransactionStop(TccEndedEvent tccEndedEvent);

  AlphaResponse coordinate(CoordinatedEvent coordinatedEvent);
  
}

==> apache-servicecomb-pack-distribution-0.7.0-src.zip: apache-servicecomb-pack-distribution-0.7.0-src/omega/omega-transaction/src/main/java/org/apache/servicecomb/pack/omega/transaction/tcc/TccEventService.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.pack.omega.transaction.tcc;

import org.apache.servicecomb.pack.omega.transaction.tcc.events.CoordinatedEvent;
import org.apache.servicecomb.pack.omega.transaction.tcc.events.ParticipationStartedEvent;
import org.apache.servicecomb.pack.omega.transaction.tcc.events.TccStartedEvent;
import org.apache.servicecomb.pack.omega.transaction.AlphaResponse;
import org.apache.servicecomb.pack.omega.transaction.tcc.events.TccEndedEvent;

public interface TccEventService {

  void onConnected();

  void onDisconnected();

  void close();

  String target();

  AlphaResponse participate(ParticipationStartedEvent participationStartedEvent);

  AlphaResponse tccTransactionStart(TccStartedEvent tccStartedEvent);

  AlphaResponse tccTransactionStop(TccEndedEvent tccEndedEvent);

  AlphaResponse coordinate(CoordinatedEvent coordinatedEvent);
  
}
